@@ -1,5 +1,5 @@
-use std::fmt;
-
+use crate::prelude::*;
+use core::fmt;
 use serde_derive::{Deserialize, Serialize};
 
 use super::error::Error;
@@ -36,7 +36,7 @@ impl fmt::Display for ClientType {
     }
 }
 
-impl std::str::FromStr for ClientType {
+impl core::str::FromStr for ClientType {
     type Err = Error;
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
@@ -53,7 +53,7 @@ impl std::str::FromStr for ClientType {
 
 #[cfg(test)]
 mod tests {
-    use std::str::FromStr;
+    use core::str::FromStr;
     use test_env_log::test;
 
     use super::ClientType;
